# PS Commands

Note: unless otherwise stated, replace any variable such as `$ComputerName` with the appropriate data.

<br>

### Remotely Fetch a (Partial) Installed Program List for $ComputerName

```powershell
Get-WmiObject win32_product -ComputerName $ComputerName | Sort-Object | select Vendor, Name, version
```

<br>

### Remotely Fetch Installed Programs from $ComputerName by searching $Column (Vendor, Name, or version) for $SearchTerm

```powershell
Get-WmiObject win32_product -ComputerName $ComputerName | Where-Object {$_.$Column -like “*$SearchTerm*”} | Sort-Object | select Vendor, Name, version
```

<br>

### Fetch AD Groups with $SearchTerm in them

```powershell
Get-ADGroup -Filter 'name -like "*$SearchTerm*"' | Sort-Object | select Name
```

<br>

### Remotely Fetch $ComputerName's Boot Time

```powershell
Get-CimInstance -ClassName Win32_OperatingSystem -ComputerName $ComputerName | slect csname, lastbootuptime
```

<br>

### Fetch $ComputerName's Group Membership

```powershell
Get-ADPrincipalGroupMembership (Get-ADComputer $ComputerName) | select-object name
```

<br>

### Fetch $Username's Group Membership

```powershell
Get-ADPrincipalGroupMembership (Get-ADUser $Username) | select-object name
```

<br>

### Fetch $ComputerName's Make & Model

```powershell
Get-CimInstance -ComputerName $ComputerName -ClassName Win32_ComputerSystem | Select-Object -Property Manufacturer, Model
```

<br>

### Fetch $ComputerName's Serial Number 

```powershell
Get-CimInstance -ComputerName $ComputerName -ClassName Win32_bios | Select-Object -Property SerialNumber
```